Module hnsw

Module hnsw 

HNSW graph implementations for centroid search.

This module provides a trait-based abstraction for HNSW indexes with an implementation backed by the usearch library.

Structs

UsearchCentroidGraph
HNSW graph implementation using the usearch library.

Traits

CentroidGraph
Trait for HNSW-based centroid graph implementations.

Functions

build_centroid_graph
Build a centroid graph using the default implementation (usearch).