VectorDbReader

Struct VectorDbReader 

pub struct VectorDbReader { /* private fields */ }
Read-only client for querying a vector database.

VectorDbReader loads a vector db from storage for read-only access. NOTE: currently the reader only works for dbs that are static as it does not have a mechanism for refreshing the centroid graph. This is deferred to a later improvement. In the interim we’ll first add support for creating a reader from a checkpoint.

Implementations

Source

impl VectorDbReader

pub async fn open(config: ReaderConfig) -> Result<Self>

Open a read-only client against an existing vector database.

Loads the centroid graph from storage. The database must have been previously initialized by a VectorDb writer.

pub async fn open_with_runtime( config: ReaderConfig, runtime: StorageReaderRuntime, ) -> Result<Self>

Open a read-only client with custom runtime options (e.g. block cache).