Serialization/deserialization for vector database storage.
This module implements the key/value encoding scheme defined in RFC 0001.
Modules
- centroid_
chunk - CentroidChunk value encoding/decoding.
- centroid_
stats - CentroidStats value encoding/decoding.
- collection_
meta - CollectionMeta value encoding/decoding.
- deletions
- Deletions value encoding/decoding.
- id_
dictionary - IdDictionary value encoding/decoding.
- key
- Key encoding/decoding for vector database records.
- metadata_
index - MetadataIndex value encoding/decoding.
- posting_
list - PostingList value encoding/decoding.
- vector_
bitmap - VectorBitmap - shared bitmap type for storing sets of vector IDs.
- vector_
data - VectorData value encoding/decoding.
Structs
- Encoding
Error - Encoding error with a descriptive message.
Enums
- Field
Type - Type discriminant for metadata field values.
- Field
Value - A metadata field value (tagged union).
- Record
Type - Record type enumeration for vector database records.
Constants
- KEY_
VERSION - Key format version (currently 0x01)
Traits
- Decode
- Trait for types that can be decoded from bytes.
- Encode
- Trait for types that can be encoded to bytes.
- Record
Key - Trait for record keys that have a record type.
Functions
- decode_
array - Decode an array of decodable items.
- decode_
fixed_ element_ array - Decode a fixed-element array (no count prefix).
- decode_
optional_ utf8 - Decode an optional non-empty UTF-8 string.
- decode_
utf8 - Decode a UTF-8 string.
- encode_
array - Encode an array of encodable items.
- encode_
fixed_ element_ array - Encode a fixed-element array (no count prefix).
- encode_
optional_ utf8 - Encode an optional non-empty UTF-8 string.
- encode_
utf8 - Encode a UTF-8 string.
- record_
type_ from_ tag - Extracts the RecordType from a RecordTag.