pub enum FieldValue {
String(String),
Int64(i64),
Float64(f64),
Bool(bool),
Vector(Vec<f32>),
}Expand description
A metadata field value (tagged union).
Used in:
VectorData: Stores actual metadata values for each vectorMetadataIndexKey: Encodes values in index keys for filtering
Encoding
This type has two encoding modes:
- Value encoding (via
Encode/Decodetraits): Little-endian, used inVectorData - Sortable encoding (via
encode_sortable/decode_sortable): Big-endian with sign-bit transformations, used inMetadataIndexKeyfor correct lexicographic ordering
Variants
String(String)
Int64(i64)
Float64(f64)
Bool(bool)
Vector(Vec<f32>)
Vector value - Not valid in metadata index keys.
Implementations
Sourceimpl FieldValue
impl FieldValue
Sourcepub fn field_type(&self) -> FieldType
pub fn field_type(&self) -> FieldType
Returns the type discriminant for this value.
Sourcepub fn encode_sortable(&self, buf: &mut BytesMut)
pub fn encode_sortable(&self, buf: &mut BytesMut)
Encode the field value for use in keys (sortable encoding).
Uses big-endian sortable encodings for numeric types:
- Int64: XOR with sign bit to make negative numbers sort before positive
- Float64: IEEE 754 sortable encoding
This encoding preserves lexicographic ordering in keys:
- Strings: Natural byte ordering via TerminatedBytes
- Integers: -100 < 0 < 100
- Floats: -1.0 < 0.0 < 1.0
- Bools: false < true
Panics
Panics if called on a Vector variant since vectors should not appear in index keys.
Sourcepub fn decode_sortable(buf: &mut &[u8]) -> Result<Self, EncodingError>
pub fn decode_sortable(buf: &mut &[u8]) -> Result<Self, EncodingError>
Decode a field value from sortable key encoding.
Errors
Returns an error if the buffer is too short or contains invalid data.
Also returns an error for Vector type since vectors should not appear in index keys.
Sourceimpl FieldValue
impl FieldValue
Sourcepub fn decode_with_dimensions(
buf: &mut &[u8],
dimensions: usize,
) -> Result<Self, EncodingError>
pub fn decode_with_dimensions( buf: &mut &[u8], dimensions: usize, ) -> Result<Self, EncodingError>
Decode a FieldValue that may be a Vector, using the provided dimensions.
This is used when decoding VectorData records where vectors are stored as fields.