VectorBitmap - shared bitmap type for storing sets of vector IDs.
This type is used by both DeletionsValue and MetadataIndexValue to
store compressed sets of vector IDs using RoaringTreemap.
Structs
- Vector
Bitmap - A compressed bitmap storing a set of vector IDs.